==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/PutLoggingConfigurationResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class PutLoggingConfigurationResponse(
    loggingConfiguration: Option[zio.aws.waf.model.LoggingConfiguration] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse = {
    import PutLoggingConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse
      .builder()
      .optionallyWith(loggingConfiguration.map(value => value.buildAwsValue()))(
        _.loggingConfiguration
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.PutLoggingConfigurationResponse.ReadOnly =
    zio.aws.waf.model.PutLoggingConfigurationResponse.wrap(buildAwsValue())
}
object PutLoggingConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.PutLoggingConfigurationResponse =
      zio.aws.waf.model.PutLoggingConfigurationResponse(
        loggingConfiguration.map(value => value.asEditable)
      )
    def loggingConfiguration
        : Option[zio.aws.waf.model.LoggingConfiguration.ReadOnly]
    def getLoggingConfiguration
        : ZIO[Any, AwsError, zio.aws.waf.model.LoggingConfiguration.ReadOnly] =
      AwsError.unwrapOptionField("loggingConfiguration", loggingConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse
  ) extends zio.aws.waf.model.PutLoggingConfigurationResponse.ReadOnly {
    override val loggingConfiguration
        : Option[zio.aws.waf.model.LoggingConfiguration.ReadOnly] = scala
      .Option(impl.loggingConfiguration())
      .map(value => zio.aws.waf.model.LoggingConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse
  ): zio.aws.waf.model.PutLoggingConfigurationResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-waf_2.13-5.17.176.2-sources.jar: zio/aws/waf/model/PutLoggingConfigurationResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PutLoggingConfigurationResponse(
    loggingConfiguration: Optional[zio.aws.waf.model.LoggingConfiguration] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse = {
    import PutLoggingConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse
      .builder()
      .optionallyWith(loggingConfiguration.map(value => value.buildAwsValue()))(
        _.loggingConfiguration
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.PutLoggingConfigurationResponse.ReadOnly =
    zio.aws.waf.model.PutLoggingConfigurationResponse.wrap(buildAwsValue())
}
object PutLoggingConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.PutLoggingConfigurationResponse =
      zio.aws.waf.model.PutLoggingConfigurationResponse(
        loggingConfiguration.map(value => value.asEditable)
      )
    def loggingConfiguration
        : Optional[zio.aws.waf.model.LoggingConfiguration.ReadOnly]
    def getLoggingConfiguration
        : ZIO[Any, AwsError, zio.aws.waf.model.LoggingConfiguration.ReadOnly] =
      AwsError.unwrapOptionField("loggingConfiguration", loggingConfiguration)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse
  ) extends zio.aws.waf.model.PutLoggingConfigurationResponse.ReadOnly {
    override val loggingConfiguration
        : Optional[zio.aws.waf.model.LoggingConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loggingConfiguration())
        .map(value => zio.aws.waf.model.LoggingConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.PutLoggingConfigurationResponse
  ): zio.aws.waf.model.PutLoggingConfigurationResponse.ReadOnly = new Wrapper(
    impl
  )
}
